@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.008;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Padre::Wx ();
 use Padre::Current;
@@ -103,7 +103,7 @@ sub colorize {
 	my ( $self, $first ) = @_;
 
 	my $doc = Padre::Current->document;
-	my $mime_type = $doc->get_mimetype;
+	my $mime_type = $doc->mimetype;
 	if ( not $d{$mime_type} ) {
 		warn("Invalid mime-type ($mime_type) passed to the Kate highlighter");
 		return;
